==> verticalpodautoscaler-model-v1-6.2.0-sources.jar: io/fabric8/verticalpodautoscaler/api/model/v1/VerticalPodAutoscalerCheckpointListFluent.java <==
package io.fabric8.verticalpodautoscaler.api.model.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface VerticalPodAutoscalerCheckpointListFluent<A extends VerticalPodAutoscalerCheckpointListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,VerticalPodAutoscalerCheckpoint item);
  public A setToItems(Integer index,VerticalPodAutoscalerCheckpoint item);
  public A addToItems(io.fabric8.verticalpodautoscaler.api.model.v1.VerticalPodAutoscalerCheckpoint... items);
  public A addAllToItems(Collection<VerticalPodAutoscalerCheckpoint> items);
  public A removeFromItems(io.fabric8.verticalpodautoscaler.api.model.v1.VerticalPodAutoscalerCheckpoint... items);
  public A removeAllFromItems(Collection<VerticalPodAutoscalerCheckpoint> items);
  public A removeMatchingFromItems(Predicate<VerticalPodAutoscalerCheckpointBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<VerticalPodAutoscalerCheckpoint> getItems();
  public List<VerticalPodAutoscalerCheckpoint> buildItems();
  public VerticalPodAutoscalerCheckpoint buildItem(Integer index);
  public VerticalPodAutoscalerCheckpoint buildFirstItem();
  public VerticalPodAutoscalerCheckpoint buildLastItem();
  public VerticalPodAutoscalerCheckpoint buildMatchingItem(Predicate<VerticalPodAutoscalerCheckpointBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<VerticalPodAutoscalerCheckpointBuilder> predicate);
  public A withItems(List<VerticalPodAutoscalerCheckpoint> items);
  public A withItems(io.fabric8.verticalpodautoscaler.api.model.v1.VerticalPodAutoscalerCheckpoint... items);
  public Boolean hasItems();
  public VerticalPodAutoscalerCheckpointListFluent.ItemsNested<A> addNewItem();
  public VerticalPodAutoscalerCheckpointListFluent.ItemsNested<A> addNewItemLike(VerticalPodAutoscalerCheckpoint item);
  public VerticalPodAutoscalerCheckpointListFluent.ItemsNested<A> setNewItemLike(Integer index,VerticalPodAutoscalerCheckpoint item);
  public VerticalPodAutoscalerCheckpointListFluent.ItemsNested<A> editItem(Integer index);
  public VerticalPodAutoscalerCheckpointListFluent.ItemsNested<A> editFirstItem();
  public VerticalPodAutoscalerCheckpointListFluent.ItemsNested<A> editLastItem();
  public VerticalPodAutoscalerCheckpointListFluent.ItemsNested<A> editMatchingItem(Predicate<VerticalPodAutoscalerCheckpointBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,VerticalPodAutoscalerCheckpointFluent<VerticalPodAutoscalerCheckpointListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> verticalpodautoscaler-model-v1-6.7.2-sources.jar: io/fabric8/verticalpodautoscaler/api/model/v1/VerticalPodAutoscalerCheckpointListFluent.java <==
package io.fabric8.verticalpodautoscaler.api.model.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface VerticalPodAutoscalerCheckpointListFluent<A extends VerticalPodAutoscalerCheckpointListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,VerticalPodAutoscalerCheckpoint item);
  public A setToItems(int index,VerticalPodAutoscalerCheckpoint item);
  public A addToItems(io.fabric8.verticalpodautoscaler.api.model.v1.VerticalPodAutoscalerCheckpoint... items);
  public A addAllToItems(Collection<VerticalPodAutoscalerCheckpoint> items);
  public A removeFromItems(io.fabric8.verticalpodautoscaler.api.model.v1.VerticalPodAutoscalerCheckpoint... items);
  public A removeAllFromItems(Collection<VerticalPodAutoscalerCheckpoint> items);
  public A removeMatchingFromItems(Predicate<VerticalPodAutoscalerCheckpointBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<VerticalPodAutoscalerCheckpoint> getItems();
  public List<VerticalPodAutoscalerCheckpoint> buildItems();
  public VerticalPodAutoscalerCheckpoint buildItem(int index);
  public VerticalPodAutoscalerCheckpoint buildFirstItem();
  public VerticalPodAutoscalerCheckpoint buildLastItem();
  public VerticalPodAutoscalerCheckpoint buildMatchingItem(Predicate<VerticalPodAutoscalerCheckpointBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<VerticalPodAutoscalerCheckpointBuilder> predicate);
  public A withItems(List<VerticalPodAutoscalerCheckpoint> items);
  public A withItems(io.fabric8.verticalpodautoscaler.api.model.v1.VerticalPodAutoscalerCheckpoint... items);
  public Boolean hasItems();
  public VerticalPodAutoscalerCheckpointListFluent.ItemsNested<A> addNewItem();
  public VerticalPodAutoscalerCheckpointListFluent.ItemsNested<A> addNewItemLike(VerticalPodAutoscalerCheckpoint item);
  public VerticalPodAutoscalerCheckpointListFluent.ItemsNested<A> setNewItemLike(int index,VerticalPodAutoscalerCheckpoint item);
  public VerticalPodAutoscalerCheckpointListFluent.ItemsNested<A> editItem(int index);
  public VerticalPodAutoscalerCheckpointListFluent.ItemsNested<A> editFirstItem();
  public VerticalPodAutoscalerCheckpointListFluent.ItemsNested<A> editLastItem();
  public VerticalPodAutoscalerCheckpointListFluent.ItemsNested<A> editMatchingItem(Predicate<VerticalPodAutoscalerCheckpointBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,VerticalPodAutoscalerCheckpointFluent<VerticalPodAutoscalerCheckpointListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
